@@ -28,6 +28,7 @@ from pyomo.core.expr.numeric_expr import (
     NPV_ProductExpression, NPV_ReciprocalExpression, NPV_SumExpression,
     NPV_UnaryFunctionExpression, PowExpression, ProductExpression,
     ReciprocalExpression, SumExpression, UnaryFunctionExpression,
+    NPV_DivisionExpression, DivisionExpression,
 )
 from pyomo.core.expr.visitor import (
     StreamBasedExpressionVisitor, identify_variables,
@@ -48,7 +49,8 @@ NPV_expressions = (
     NPV_AbsExpression, NPV_ExternalFunctionExpression,
     NPV_NegationExpression, NPV_PowExpression,
     NPV_ProductExpression, NPV_ReciprocalExpression, NPV_SumExpression,
-    NPV_UnaryFunctionExpression)
+    NPV_UnaryFunctionExpression, NPV_DivisionExpression,
+)
 
 
 def _MCPP_lib():
@@ -237,7 +239,10 @@ class MCPP_visitor(StreamBasedExpressionVisitor):
             else:
                 ans = self.mcpp.try_binary_fcn(self.mcpp.powerx, data[0], data[1])
         elif isinstance(node, ReciprocalExpression):
+            # Note: unreachable after ReciprocalExpression was removed
             ans = self.mcpp.try_unary_fcn(self.mcpp.reciprocal, data[0])
+        elif isinstance(node, DivisionExpression):
+            ans = self.mcpp.try_binary_fcn(self.mcpp.divide, data[0], data[1])
         elif isinstance(node, NegationExpression):
             ans = self.mcpp.negation(data[0])
         elif isinstance(node, AbsExpression):
