@@ -8,12 +8,8 @@
 #  This software is distributed under the 3-clause BSD License.
 #  ___________________________________________________________________________
 
-try:
-    import numpy as np
-    numpy_available = True
-except ImportError:
-    numpy_available = False
+from .. import numpy_available, scipy_available
 
-if numpy_available:
+if numpy_available and scipy_available:
     from .nlp import AmplNLP, PyomoNLP
-    from .nlp_compositions import TwoStageStochasticNLP
\ No newline at end of file
+    from .nlp_compositions import TwoStageStochasticNLP
