@@ -16,14 +16,14 @@ from six import iteritems, itervalues, iterkeys
 from six.moves import xrange
 from weakref import ref as weakref_ref
 
-from pyomo.util.timing import ConstructionTimer
-from pyomo.util.plugin import Plugin, implements
+from pyomo.common.timing import ConstructionTimer
+from pyomo.common.plugin import Plugin, implements
 
 from pyomo.core.base.component import ComponentData
 from pyomo.core.base.indexed_component import IndexedComponent
 from pyomo.core.base.misc import apply_indexed_rule, tabular_writer
 from pyomo.core.base.numvalue import NumericValue, value
-from pyomo.core.base.plugin import register_component, \
+from pyomo.core.base.plugin import ModelComponentFactory, \
     IPyomoScriptModifyInstance, TransformationFactory
 
 logger = logging.getLogger('pyomo.core')
@@ -74,7 +74,7 @@ class _ConnectorData(ComponentData, NumericValue):
         """
         return False
 
-    def _potentially_variable(self):
+    def is_potentially_variable(self):
         """Return True as connectors may (should!) contain variables"""
         return True
 
@@ -118,6 +118,7 @@ class _ConnectorData(ComponentData, NumericValue):
 
 
 
+@ModelComponentFactory.register("A bundle of variables that can be manipilated together.")
 class Connector(IndexedComponent):
     """A collection of variables, which may be defined over a index
 
@@ -142,6 +143,8 @@ class Connector(IndexedComponent):
     def __new__(cls, *args, **kwds):
         if cls != Connector:
             return super(Connector, cls).__new__(cls)
+        logger.warning("DEPRECATED: The Connector component is deprecated. "
+            "It has been replaced by Port in the pyomo.network package.")
         if args == ():
             return SimpleConnector.__new__(SimpleConnector)
         else:
@@ -275,9 +278,6 @@ class IndexedConnector(Connector):
     pass
 
 
-register_component(
-    Connector, "A bundle of variables that can be manipilated together.")
-
 
 class ConnectorExpander(Plugin):
     implements(IPyomoScriptModifyInstance)
