@@ -158,10 +158,10 @@ class TwoTermDisj(unittest.TestCase):
         self.assertEqual(
             str(cons.body),
             "(%s*d[0].indicator_var + %s)*("
-            "_pyomo_gdp_chull_relaxation.relaxedDisjuncts[0].x*"
-            "(1/(%s*d[0].indicator_var + %s)) + "
-            "(_pyomo_gdp_chull_relaxation.relaxedDisjuncts[0].y*"
-            "(1/(%s*d[0].indicator_var + %s)))**2) - "
+            "_pyomo_gdp_chull_relaxation.relaxedDisjuncts[0].x"
+            "/(%s*d[0].indicator_var + %s) + "
+            "(_pyomo_gdp_chull_relaxation.relaxedDisjuncts[0].y/"
+            "(%s*d[0].indicator_var + %s))**2) - "
             "%s*(0.0 + 0.0**2)*(1 - d[0].indicator_var) "
             "- 14.0*d[0].indicator_var"
             % (EPS_1, EPS, EPS_1, EPS, EPS_1, EPS, EPS))
