@@ -14,11 +14,6 @@ import time
 import itertools
 import math
 
-try:
-    from collections import OrderedDict
-except ImportError:                         #pragma:nocover
-    from ordereddict import OrderedDict
-
 import pyutilib.misc
 from pyutilib.pyro import shutdown_pyro_components
 
@@ -189,15 +184,12 @@ class ExtensiveFormAlgorithm(PySPConfiguredObject):
 
     def close(self):
         self.destroy_ef()
-        if self._solver is not None:
-            self._solver.deactivate()
         if self._solver_manager is not None:
             if isinstance(self._solver_manager,
                           pyomo.solvers.plugins.smanager.\
                           pyro.SolverManager_Pyro):
                 if self.get_option("pyro_shutdown_workers"):
                       self._solver_manager.shutdown_workers()
-            self._solver_manager.deactivate()
         self._solver_manager = None
         self._manager = None
 
@@ -620,7 +612,7 @@ class EFSolver(SPSolver, PySPConfiguredObject):
                     #        stage._cost_variable
                     #    stage_cost_obj = \
                     #        instance.find_component(cost_variable_name)[cost_variable_index]
-                    #    if not stage_cost_obj.is_expression():
+                    #    if not stage_cost_obj.is_expression_type():
                     #        refvar = ComponentUID(stage_cost_obj,cuid_buffer=tmp).\
                     #            find_component(reference_model)
                     #        refvar.value = stage_cost_obj.value
