@@ -568,21 +568,21 @@ class Test(unittest.TestCase):
             self.assertEqual(scenario_tree.contains_bundles(), False)
             # check that we can modify the networkx tree to redefine
             # bundles
-            nx_tree.node["s1"]["bundle"] = 0
-            nx_tree.node["s2"]["bundle"] = 0
-            nx_tree.node["s3"]["bundle"] = 0
+            nx_tree.nodes["s1"]["bundle"] = 0
+            nx_tree.nodes["s2"]["bundle"] = 0
+            nx_tree.nodes["s3"]["bundle"] = 0
             scenario_tree = factory.generate_scenario_tree()
             self.assertEqual(scenario_tree.contains_bundles(), True)
             self.assertEqual(len(scenario_tree.bundles), 1)
-            nx_tree.node["s1"]["bundle"] = 0
-            nx_tree.node["s2"]["bundle"] = 1
-            nx_tree.node["s3"]["bundle"] = 2
+            nx_tree.nodes["s1"]["bundle"] = 0
+            nx_tree.nodes["s2"]["bundle"] = 1
+            nx_tree.nodes["s3"]["bundle"] = 2
             scenario_tree = factory.generate_scenario_tree()
             self.assertEqual(scenario_tree.contains_bundles(), True)
             self.assertEqual(len(scenario_tree.bundles), 3)
-            nx_tree.node["s1"]["bundle"] = None
-            nx_tree.node["s2"]["bundle"] = None
-            nx_tree.node["s3"]["bundle"] = None
+            nx_tree.nodes["s1"]["bundle"] = None
+            nx_tree.nodes["s2"]["bundle"] = None
+            nx_tree.nodes["s3"]["bundle"] = None
             scenario_tree = factory.generate_scenario_tree()
             self.assertEqual(scenario_tree.contains_bundles(), False)
 
